@@ -14,24 +14,26 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.11'
+__version__ = '0.2.12'
 
-__all__ = ['ANY_BOOLEAN',
-           'ANY_DICTIONARY',
-           'ANY_FLOAT',
-           'ANY_INTEGER',
-           'ANY_LIST',
-           'ANY_SLICE',
-           'ANY_STRING',
-           'ANY_TUPLE',
-           'ANY_VALUE',
-           'ANY_VALUES',
-           'AT_LEAST_ONCE',
-           'NEVER',
-           'UnitTests',
-           'create_mock',
-           'verify',
-           'when']
+__all__ = [
+    'ANY_BOOLEAN',
+    'ANY_DICTIONARY',
+    'ANY_FLOAT',
+    'ANY_INTEGER',
+    'ANY_LIST',
+    'ANY_SLICE',
+    'ANY_STRING',
+    'ANY_TUPLE',
+    'ANY_VALUE',
+    'ANY_VALUES',
+    'AT_LEAST_ONCE',
+    'NEVER',
+    'UnitTests',
+    'create_mock',
+    'verify',
+    'when'
+]
 
 try:
     from importlib import import_module
